==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/nb.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Bruksspørreskjema",
    "Sent on: {on}" : "Sendt den: {on}",
    "An error occurred while sending your report." : "Feil under forsendelse av din rapport.",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Programliste <em>(Status for hvert program: Navn, versjon)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Database-miljø <em>(type, versjon, databasestørrelse)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Krypteringsinformasjon <em>(er den påskrudd?, hva er forvalgt modul)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Antall ressurser <em>(per type og tilgangsinnstilling)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-miljø <em>(versjon, minnegrense, maks. kjøringstid, maks. filstørrelse)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Tjenerinstallasjonsdetaljer <em>(versjon, minnehurtiglager brukt, status for låsing/forhåndsvisninger, avatarer)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistikk<em>(antall: filer, brukere, lager per type, kommentarer og merkelapper)</em>",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Du kan hjelpe til med å forbedre Nextcloud ved å sende oss noe anonymisert data om ditt nåværende oppsett og bruk. Du kan skru det av igjen når som helst fra administrasjonsinnstillingene.",
    "Not now" : "Ikke nå",
    "Send usage" : "Send bruk",
    "Never" : "Aldri",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Du kan hjelpe til med å forbedre Nextcloud ved å sende oss noe data om ditt nåværende oppsett og bruk.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Vi tar ditt personvern på alvor. Å sende data er skrudd av som forvalg, og skulle du velge å skru det på, vil de ble anonymisert først, og du vil bli gitt valget om hva du vil dele. Når du mottar en rapport, vil den forrige bli fjernet. Last opp en tom rapport for å slette all data som lagres på tjeneren for øyeblikket.",
    "Send new report now" : "Send ny rapport nå",
    "Send usage survey monthly" : "Send bruksspørreundersøkelse månedlig ",
    "Data to send" : "Data å sende",
    "Last report" : "Siste rapport",
    "Sent on: %s" : "Sendt den: %s",
    "You can help us to improve Nextcloud be sending us some data about your current setup and usage." : "Du kan hjelpe oss å forbedre Nextcloud ved å sende oss noe data om ditt nåværende oppsett og bruk.",
    "We take your privacy seriously. The data are anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server." : "Vi tar ditt personvern seriøst. Dataene er anonymisert og du kan aktivere/deaktivere når som helst, som standard er det alltid deaktivert. Under kan du også justere hvilke data som sender og du kan alltid se siste rapporten som er sendt oss. Når tjeneren mottar en ny rapport fra din instans blir alle tidligere rapporter fjernet. Hvis du deaktiverer en av innstillingene under kan du sende en ny rapport, og dermed slette dataene som er lagret på tjeneren vår.",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Du kan hjelpe til med å forbedre Nextcloud ved å sende oss noe data om ditt nåværende oppsett og bruk.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Vi tar ditt personvern seriøst. Dataene er anonymisert og du kan aktivere/deaktivere når som helst, som standard er det alltid deaktivert. Under kan du også justere hvilke data som sender og du kan alltid se siste rapporten som er sendt oss. Når tjeneren mottar en ny rapport fra din instans blir alle tidligere rapporter fjernet. Hvis du deaktiverer en av innstillingene under kan du sende en ny rapport, og dermed slette dataene som er lagret på tjeneren vår."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/nb.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Bruksspørreskjema",
    "Sent on: {on}" : "Sendt den: {on}",
    "An error occurred while sending your report." : "Feil under forsendelse av din rapport.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Programliste <em>(for hvert program: navn, versjon, påslått status)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Database-miljø <em>(type, versjon, databasestørrelse)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Krypteringsinformasjon <em>(er den påskrudd?, hva er forvalgt modul)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Antall ressurser <em>(per type og tilgangsinnstilling)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-miljø <em>(versjon, minnegrense, maks. kjøringstid, maks. filstørrelse)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Tjenerinstallasjonsdetaljer <em>(versjon, minnehurtiglager brukt, status for låsing/forhåndsvisninger/avatarer)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistikk<em>(antall: filer, brukere, lager per type, kommentarer og merkelapper)</em>",
    "Help improve Nextcloud" : "Hjelp til med å forbedre Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Du kan hjelpe til med å forbedre Nextcloud ved å sende oss noe anonymisert data om ditt nåværende oppsett og bruk. Du kan skru det av igjen når som helst fra administrasjonsinnstillingene.",
    "Not now" : "Ikke nå",
    "Send usage" : "Send bruk",
    "Never" : "Aldri",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Du kan hjelpe til med å forbedre Nextcloud ved å sende oss noe data om ditt nåværende oppsett og bruk.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Vi tar ditt personvern på alvor. Å sende data er skrudd av som forvalg, og skulle du velge å skru det på, vil de ble anonymisert først, og du vil bli gitt valget om hva du vil dele. Når du mottar en rapport, vil den forrige bli fjernet. Last opp en tom rapport for å slette all data som lagres på tjeneren for øyeblikket.",
    "Send new report now" : "Send ny rapport nå",
    "Send usage survey monthly" : "Send bruksspørreundersøkelse månedlig ",
    "Data to send" : "Data å sende",
    "Last report" : "Siste rapport",
    "Sent on: %s" : "Sendt den: %s",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Programliste <em>(Status for hvert program: Navn, versjon)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Tjenerinstallasjonsdetaljer <em>(versjon, minnehurtiglager brukt, status for låsing/forhåndsvisninger, avatarer)</em>",
    "You can help us to improve Nextcloud be sending us some data about your current setup and usage." : "Du kan hjelpe oss å forbedre Nextcloud ved å sende oss noe data om ditt nåværende oppsett og bruk.",
    "We take your privacy seriously. The data are anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server." : "Vi tar ditt personvern seriøst. Dataene er anonymisert og du kan aktivere/deaktivere når som helst, som standard er det alltid deaktivert. Under kan du også justere hvilke data som sender og du kan alltid se siste rapporten som er sendt oss. Når tjeneren mottar en ny rapport fra din instans blir alle tidligere rapporter fjernet. Hvis du deaktiverer en av innstillingene under kan du sende en ny rapport, og dermed slette dataene som er lagret på tjeneren vår.",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Du kan hjelpe til med å forbedre Nextcloud ved å sende oss noe data om ditt nåværende oppsett og bruk.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Vi tar ditt personvern seriøst. Dataene er anonymisert og du kan aktivere/deaktivere når som helst, som standard er det alltid deaktivert. Under kan du også justere hvilke data som sender og du kan alltid se siste rapporten som er sendt oss. Når tjeneren mottar en ny rapport fra din instans blir alle tidligere rapporter fjernet. Hvis du deaktiverer en av innstillingene under kan du sende en ny rapport, og dermed slette dataene som er lagret på tjeneren vår."
},
"nplurals=2; plural=(n != 1);");
